#
# spec file for package postgresql-plr
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define pgversion 94
%define sname plr
# Make our path like what postgresql packager decide

%if 0%{?sles_version} == 11
%define extension shlib=plr.so soname=plr.so
%endif
%define pgshare %(pg_config --sharedir)
%define pkglibs %(pg_config --pkglibdir)
%define extensiondir %{pgshare}/extension

Summary:        PL/R - R Procedural Language for PostgreSQL
License:        GPL-2.0+
Group:          Productivity/Databases/Servers
Name:           postgresql%{pgversion}-%{sname}
Version:        8.3.0.16
Release:        4.4
# Source:       https://github.com/jconway/plr
Source0:        %{sname}-%{version}.tar.gz
Source1:        readme.SUSE
Patch0:         patch-Makefile-ldflags.patch
Url:            http://www.joeconway.com/plr/
BuildRequires:  R-base
BuildRequires:  R-base-devel
BuildRequires:  pkg-config
BuildRequires:  post-build-checks
BuildRequires:  postgresql%{pgversion}-devel
BuildRequires:  postgresql%{pgversion}-server
Requires:       R-base
Requires:       postgresql%{pgversion}-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PL/R is a loadable procedural language that enables you to write PostgreSQL
functions and triggers in the R programming language. PL/R offers most (if 
not all) of the capabilities a function writer has in the R language.
 
Commands are available to access the database via the PostgreSQL Server
Programming Interface (SPI) and to raise messages via elog() . There is no
way to access internals of the database backend. However the user is able 
to gain OS-level access under the permissions of the PostgreSQL user ID, 
as with a C function. Thus, any unprivileged database user should not be 
permitted to use this language. It must be installed as an untrusted 
procedural language so that only database superusers can create functions 
in it. The writer of a PL/R function must take care that the function cannot
be used to do anything unwanted, since it will be able to do anything that 
could be done by a user logged in as the database administrator.
 
An implementation restriction is that PL/R procedures cannot be used to 
create input/output functions for new data types.
 

%package doc
Summary:        Documentation for PL/R - R Procedural Language for PostgreSQL
Group:          Productivity/Databases/Servers

%description doc
PL/R is a loadable procedural language that enables you to write PostgreSQL
functions and triggers in the R programming language. PL/R offers most (if 
not all) of the capabilities a function writer has in the R language.
 
This package contain the associated documentation 


%prep
# plr.so know where R is located
%setup -q -n %{sname}
%patch0 -p1
# Need to fix spurious rights in doc and root
find ./ -type f -exec chmod 0644 {} \;

%build
# Picked from main obs postgresql
export CFLAGS="%optflags $SP"
# uncomment the following line to enable the stack protector
CFLAGS="$CFLAGS -fstack-protector"

#Rpath?
LDFLAGS="$LDFLAGS -Wl,-rpath,%_libdir/R/lib"
USE_PGXS=1 %__make %{?extension} %{?_smp_mflags}; 

%install
%{__mkdir} -p %{buildroot}/etc/ld.so.conf.d/
# okay keep this method until using rpath is completed
cat  > %{buildroot}/etc/ld.so.conf.d/%{name}.conf <<EOF
# postgresql-plr need to find where R is installed
%{_libdir}/R
%{_libdir}/R/lib
EOF

# All the right location could be found with pg_config 
# USE_PGXS=1 %%__make install
%{__install} -d -m 0755 %{buildroot}/%{pkglibs}
%{__install} -m 755 %{sname}.so %{buildroot}/%{pkglibs}/%{sname}.so
%{__install} -d -m 0755 %{buildroot}/%{extensiondir}
%{__install} -p -m 644 %{sname}*.sql %{buildroot}%{extensiondir}/
%{__install} -p -m 644 %{sname}.control %{buildroot}%{extensiondir}/%{sname}.control

cp -a %{S:1} .

%post -p /sbin/ldconfig 

%postun -p /sbin/ldconfig 

%files
%defattr(644, root, root, 0755)
%doc README.plr 
%doc readme.SUSE 
%dir %{extensiondir}/
%{extensiondir}/%{sname}.control
%{extensiondir}/%{sname}*.sql
%config /etc/ld.so.conf.d/%{name}.conf
%defattr(755, root, root, 0755)
%dir %{pkglibs}
%{pkglibs}/%{sname}.so

%files doc 
%defattr(644, root, root, 0755)
%doc doc/*
%doc expected/plr.out

%changelog
* Mon Dec 21 2015 bruno@ioda-net.ch
- Fix postun/postin ldconfig call (see comment in sr#345782)
* Fri Feb 13 2015 bruno@ioda-net.ch
- Update to last upstream tar.gz
  Due to missing root plr, and documentation (Conway)
- Removed upgrade alter extension, this doesn't work yet
* Mon Feb  9 2015 bruno@ioda-net.ch
- Update to upstream 8.3.0.16
  Update for PostgreSQL 9.5dev compatibility
  Update copyrights
  Add check and throw an error when don't have an expectedDesc.
  Remove autocommit setting -- it has been removed in PostgreSQL
  9.5, and it has been ineffective for a long time.
    Reported by Peter E.
  Fix RPM spec file (redhat)
- Added support to postgresql94 packages
- modified patches: redone for 8.0.16
  * patch-Makefile-ldflags.patch
* Thu Jan 23 2014 bruno@ioda-net.ch
- Revised year
- Added pre_checkin.sh methode to create variant packages
* Fri Dec  6 2013 bruno@ioda-net.ch
- Update to upstream 8.0.15
  Update for PostgreSQL 9.3 compatibility
  Ensure certain errors in R code do not crash postgres
  Unbreak compilation with older versions of postgres not having rangetypes
  Allow use of OUT parameters
- modified patches: redone for 8.0.15
  * patch-Makefile-ldflags.patch
* Mon Nov 18 2013 bruno@ioda-net.ch
- Packaging postgresql-plr
  Added postgresql-server as BuildRequires so rpmlint doesn't complain about
  owner of postgresql base install directory
* Fri Sep 27 2013 bruno@ioda-net.ch
- split postgresql-plr to postgresql version aligned
  postgresql91-plr linked to postgresql91
  postgresql92-plr linked to postgresql92
  postgresql93-plr linked to postgresql93
* Wed Jul 24 2013 bruno@ioda-net.ch
- Upgrade to 8.3.0.14
  Update copyright for 2013
  Remove hack to take signal back from R interpreter (Mark Kirkwood)
  Set R_SignalHandlers = 0, the proper way to prevent R from taking signals in the first place (Mark Kirkwood)
  Adjust RPM spec file
  As of pg9.2 the syntax "LANGUAGE 'C'" no longer works. Use "LANGUAGE C" instead.
  The MacPorts installation has the header filed distributed across two different directories, so there is no single "rincludedir" to query from pkg-config. Instead, do it the proper way and ask pkg-config for the cflags, which should work for all installation variants. (Peter Eisentraut)
* Wed Jan  2 2013 darin@darins.net
  * Upgrade to 8.3.0.13.1
  - Fix CREATE FUNCTION statements so that they work
  with PostgreSQL 9.2.x
* Mon Apr 16 2012 bruno@ioda-net.ch
- Make factory happy added R-base as Build-Require
* Sun Apr  1 2012 bruno@ioda-net.ch
- Fix formatting & licence scheme
* Fri Mar 30 2012 bruno@ioda-net.ch
- Fix installation directory : goes to extension now
- Added missing expected plr.out to doc as sample howto
* Sat Mar  3 2012 bruno@ioda-net.ch
- Split documentation to postgresql-plr
- Add more informations (first step and test to readme.SUSE)
- Try to use -rpath (following darix advise) but no success
* Mon Oct 17 2011 bruno@ioda-net.ch
  * Upgrade to 8.3.0.13
  - Fix Makefile so that msvc scripts can process it successfully
  - Add support for pgsql 9.1 CREATE EXTENSION
  - Put in safeguard to prevent attempted return of non-data (e.g.
  closure) types from R unless the pg return type is BYTEA
  - Correct thinko from earlier pass-by-val array optimization
  - Fix crashbug related to conversion of R data.frame to Postgres
  array on function return
  - Add plr_version() function: outputs a version string
  - New feature: allow PL/R functions to be declared and used
  as WINDOW functions
  - Minor fixes for compiler warnings by updated gcc
  - Fix missing calls to UNPROTECT. Report and patch by Ben Leiting.
  - Take SIGINT back into Postgres control from R. Report and test case
  by Terry Schmitt.
  - Don't try to free an array element value when the array element is NULL
  - Allow pg.spi.prepare/pg.spi.execp to use parameters which are 1D arrays-
* Fri Jun 17 2011 bruno@ioda-net.ch
- Fixed spurious perms
* Mon Jun 13 2011 bruno@ioda-net.ch
- Try to fix folders installation
* Wed Jun  8 2011 bruno@ioda-net.ch
- First spec version for obs
